@@ -1,7 +1,7 @@
 ###
-### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2013
+### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2014
 #
-`model.matrix.mvmeta` <-
+model.matrix.mvmeta <-
 function(object, ...) {
 #
 ################################################################################
